using System;
using System.Collections.ObjectModel;
using System.Linq;
using IposiGospodDemo.Dtos;
using IposiGospodDemo.Helpers;
using ReactiveUI;

namespace IposiGospodDemo.ViewModels;

public class SponsorshipOverviewWindowViewModel : ViewModelBase
{
    private ObservableCollection<SponsorshipOverViewCharityDto> _charities;
    public ObservableCollection<SponsorshipOverViewCharityDto> Charities
    {
        get => _charities;
        set => this.RaiseAndSetIfChanged(ref _charities, value);
    }
    
    private decimal _charitiesSum;

    public decimal CharitiesSum
    {
        get => _charitiesSum;
        set => this.RaiseAndSetIfChanged(ref _charitiesSum, value);
    }

    public SponsorshipOverviewWindowViewModel()
    {
        LoadData();
    }

    private void LoadData()
    {
        Charities = new(DbHelper.Database.Charities
            .Select(c => new SponsorshipOverViewCharityDto
            {
                CharityName = c.CharityName,
                CharityLogo = c.CharityLogo,
                SponsorshipAmount = c.Registrations
                    .SelectMany(r => r.Sponsorships)
                    .Sum(s => s.Amount)
            })
            .ToList());
        CharitiesSum = Charities.Sum(c => c.SponsorshipAmount);
        Console.WriteLine(Charities.Count);
    }
}